@@ -98,6 +98,17 @@ class KeenClient(object):
                       timestamp=timestamp)
         self.persistence_strategy.persist(event)
 
+    def add_events(self, events):
+        """ Adds a batch of events
+
+        Depending on the persistence strategy of the client,
+        this will either result in the event being uploaded to Keen
+        immediately or will result in saving the event to some local cache.
+
+        :param events: dictionary of events
+        """
+        self.persistence_strategy.batch_persist(events)
+
     def count(self, event_collection, timeframe=None, timezone=None, interval=None, filters=None, group_by=None):
         """ Performs a count query
 
@@ -357,4 +368,4 @@ class KeenClient(object):
         if steps:
             params["steps"] = json.dumps(steps)
 
-        return params
\ No newline at end of file
+        return params
